/*
 * Copyright (C) 2006, 2007 Anders Brander <anders@brander.dk> and 
 * Anders Kvist <akv@lnxbx.dk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef TOOLBOX_H
#define TOOLBOX_H
 
extern void scale_expand_set(gboolean expanded);
extern void gui_toolbox_add_widget(GtkWidget *widget);
extern GtkWidget * gui_toolbox_add_tool_frame(GtkWidget *widget, gchar *title);
extern GtkWidget *make_toolbox(RS_BLOB *rs);

extern GtkLabel *infolabel;

#endif /* TOOLBOX_H */
